..
    This file is part of Invenio.
    Copyright (C) 2015-2020 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_assets.ext
   :members:

Webpack
-------

.. automodule:: invenio_assets.webpack
   :members:

Command Line Interface
----------------------

.. automodule:: invenio_assets.cli
   :members:
